//	BossFungus.cpp - A ginormous fungus.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "BossFungus.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "GamePlay.h"
#include "Random.h"

//------------------------------------------------------------------------------
uint32_t BossFungus::image = 0;

//------------------------------------------------------------------------------
BossFungus::BossFungus():
xPos(1280.0f),
yPos(800.0f-461.0f-32.0f),
health(18),
sporeCount(60),
redFade(0.0f)
{
	
}

//------------------------------------------------------------------------------
BossFungus::~BossFungus()
{
	
}

//------------------------------------------------------------------------------
void BossFungus::move(GamePlay *gp)
{
	if(xPos > (1280.0f-512.0f))
	{
		xPos -= 1.0f;
		if(xPos <= (1280.0f-512.0f))
			gp->displayEyeText();
	}

	--sporeCount;
	if(sporeCount <= 0)
	{
		sporeCount = 40;
		sporeCount += (int)(Random::getGlobal().getRandomFloat() * 29.9999f);

		gp->addPinkSpore(getEyeX(), getEyeY());
	}
}

//------------------------------------------------------------------------------
void BossFungus::draw(Drawer *d)
{
	float fade = 1.0f-redFade;

	if(!image)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::bossfungus_png, Images::bossfungus_pngSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	d->drawImage(image, xPos, yPos, 1.0f, 1.0f, 1.0f, fade, fade);

	if(redFade > 0.0f)
		redFade -= 0.02f;
}

//------------------------------------------------------------------------------
void BossFungus::decrementHealth()
{
	--health;
	redFade = 1.0f;
}
