//	BossFungus.h - A ginormous fungus.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef BOSSFUNGUS_H_
#define BOSSFUNGUS_H_

#include <stdint.h>

class Drawer;
class GamePlay;

///	A ginormous fungus.
class BossFungus
{
  public:
	///	Constructor.
	BossFungus();
	///	Destructor.
	~BossFungus();

	///	Moves the fungus.
	void move(GamePlay *gp);
	///	Draws the fungus.
	void draw(Drawer *d);

	///	Decrements the boss' health.
	void decrementHealth();

	///	Returns true if the boss is still moving towards the player.
	bool getMoving() const {return (xPos > (1280.0f-512.0f));};
	///	Returns the boss' position.
	float getX() const {return xPos;};
	///	Returns the boss' position.
	float getY() const {return yPos;};
	///	Returns the width of the boss.
	float getWidth() const {return 512.0f;};
	///	Returns the height of the boss.
	float getHeight() const {return 461.0f;};
	///	Returns the position of the boss' eye.
	float getEyeX() const {return xPos + 111.0f;};
	///	Returns the position of the boss' eye.
	float getEyeY() const {return yPos + 194.0f;};
	///	Returns the radius of the boss' eye.
	float getEyeRadius() const {return 33.0f;};
	///	Returns the boss' health.
	int getHealth() const {return health;};
  private:
	///	The boss' image.
	static uint32_t image;

	///	The boss' position.
	float xPos;
	///	The boss' position.
	float yPos;
	///	The boss' health.
	int health;

	///	Used to determine when to fire pink spores at the player.
	int sporeCount;
	///	Used to fade the boss red when its eye is hit.
	float redFade;
};

#endif
