//	Bullet.h - Bullet fired from a weapon toadstool.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef BULLET_H_
#define BULLET_H_

#include <stdint.h>

class Drawer;

///	Bullet fired from a weapon toadstool.
class Bullet
{
  public:
	///	Constructor.
	Bullet(float x, float y, float xD, float yD, float rot);
	///	Destructor.
	~Bullet();

	///	Moves the bullet.
	bool move();
	///	Draws the bullet.
	void draw(Drawer *d);

	///	Returns the bullet's position.
	float getX() const {return xPos;};
	///	Returns the bullet's position.
	float getY() const {return yPos;};
	///	Returns the bullet's radius.
	float getRadius() const {return 5.0f;};
  private:
	///	The bullet's image.
	static uint32_t image;

	///	The bullet's position.
	float xPos;
	///	The bullet's position.
	float yPos;
	///	The bullet's direction.
	float xDir;
	///	The bullet's direction.
	float yDir;
	///	The bullet's rotation.
	float rotation;
};

#endif
