//	FadingText.cpp - Simple class for displaying some text and then fading it
//					 out.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "FadingText.h"
#include "NiallsDrawingLib/Drawer.h"

using namespace std;

//------------------------------------------------------------------------------
FadingText::FadingText():
xPos(0.0f),
yPos(0.0f),
width(1024.0f),
red(1.0f),
green(1.0f),
blue(1.0f),
font(0),
length(240.0f),
index(91.0f)
{
	
}

//------------------------------------------------------------------------------
FadingText::~FadingText()
{
	
}

//------------------------------------------------------------------------------
void FadingText::draw(Drawer *d)
{
	float alpha;
	const float fadeSection = length - (length/3.0f);

	if(index >= length)
		return;

	if(index < fadeSection)
		alpha = 1.0f;
	else
		alpha = 1.0f - ((index-fadeSection)/(length-fadeSection));

	index += 0.5f;

	d->drawText(text, font, xPos, yPos, width, 1.0f, red, green, blue, alpha);
}

//------------------------------------------------------------------------------
void FadingText::setPosition(float x, float y, float w)
{
	xPos = x;
	yPos = y;
	width = w;
}

//------------------------------------------------------------------------------
void FadingText::setColour(float r, float g, float b)
{
	red = r;
	green = g;
	blue = b;
}

//------------------------------------------------------------------------------
void FadingText::setFont(uint32_t val)
{
	font = val;
}

//------------------------------------------------------------------------------
void FadingText::trigger(const string& t, float time)
{
	text = t;
	length = time;
	index = 0.0f;
}
