//	FungusFactory.cpp - Generates fungi.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifdef DEBUG
#pragma warning(disable : 4786) //Stupid MS headers...
#endif

#include "FungusFactory.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "FilePath.h"
#include "Random.h"
#include "GameCounter.h"
#include "Sounds.h"

#include "tinyxml/tinyxml.h"

using namespace std;

vector<FungusFactory::FungusType> FungusFactory::fungi;

//------------------------------------------------------------------------------
FungusFactory::FungusFactory():
lastFungus(0)
{
	int i;
	FilePath path;
	FilePath fungiDir = FilePath::getDataFilesDir().getChild("fungi");

	if(fungi.size() == 0)
	{
		for(i=0;i<fungiDir.getNumChildren();++i)
		{
			path = fungiDir.getChild(i);
			if(path.getExtension() == "xml")
			{
				TiXmlElement *root;
				TiXmlElement *tempEl;
				FungusType fungus;

				TiXmlDocument doc(path.getPath());

				if(doc.LoadFile())
				{
					root = doc.FirstChildElement("Fungus");

					if(root)
					{
						fungus.name = root->Attribute("name");

						for(tempEl=root->FirstChildElement("CollisionBox");
							tempEl!=0;
							tempEl=tempEl->NextSiblingElement())
						{
							BoundingBox box;

							tempEl->QueryFloatAttribute("x", &box.x);
							tempEl->QueryFloatAttribute("y", &box.y);
							tempEl->QueryFloatAttribute("width", &box.w);
							tempEl->QueryFloatAttribute("height", &box.h);

							fungus.collisionBoxes.push_back(box);
						}

						fungus.image = 0;
						fungus.scannedVal = 0.0f;
						fungi.push_back(fungus);
					}
				}
			}
		}
	}
	else
	{
		for(i=0;i<fungi.size();++i)
			fungi[i].scannedVal = 0.0f;
	}
}

//------------------------------------------------------------------------------
FungusFactory::~FungusFactory()
{
	
}

//------------------------------------------------------------------------------
void FungusFactory::loadImages(Drawer *d)
{
	int i, j;
	FilePath fungiDir = FilePath::getDataFilesDir().getChild("fungi");
	FilePath path;
	ImageLoader imLoad;
	ImageData imData;

	if(fungi.size() > 0)
	{
		if(fungi[0].image != 0)
			return;

		j = 0;
		for(i=0;i<fungiDir.getNumChildren();++i)
		{
			path = fungiDir.getChild(i);

			if(path.getExtension() == "png")
			{
				imData = imLoad.loadImage(path.getPath());
				fungi[j].image = d->loadImage(imData.data,
											  imData.width,
											  imData.height);
				fungi[j].width = imData.width;
				fungi[j].height = imData.height;
				++j;
				if(j >= fungi.size())
					break;
			}
		}
	}
}

//------------------------------------------------------------------------------
Fungus *FungusFactory::getRandomFungus()
{
	Fungus *retval = 0;
	int tempint = lastFungus;
	float scale;

	while(tempint == lastFungus)
		tempint = (int)(Random::getGlobal().getRandomFloat() * (fungi.size()-0.0001f));
	lastFungus = tempint;

	if(Random::getGlobal().getRandomFloat() > 0.5f)
		scale = 1.0f;
	else
		scale = -1.0f;

	return new Fungus(fungi[tempint].name,
					  fungi[tempint].image,
					  fungi[tempint].width,
					  fungi[tempint].height,
					  fungi[tempint].collisionBoxes,
					  scale);
}

//------------------------------------------------------------------------------
void FungusFactory::incScannedVal(const string& name)
{
	int i;

	for(i=0;i<fungi.size();++i)
	{
		if(fungi[i].name == name)
		{
			fungi[i].scannedVal += 0.005f;
			if(fungi[i].scannedVal >= 1.0f)
			{
				GameCounter::getInstance().incrementCount("FungiScanned");
				Sounds::getInstance().playSound(Sounds::ScanComplete);
			}

			break;
		}
	}
}

//------------------------------------------------------------------------------
float FungusFactory::getScannedVal(const string& name) const
{
	int i;
	float retval = 0.0f;

	for(i=0;i<fungi.size();++i)
	{
		if(fungi[i].name == name)
		{
			retval = fungi[i].scannedVal;
			break;
		}
	}

	return retval;
}
