//	FungusFactory.h - Generates fungi.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef FUNGUSFACTORY_H_
#define FUNGUSFACTORY_H_

#include "Fungus.h"

///	Generates fungi.
class FungusFactory
{
  public:
	///	Constructor.
	/*!
		Fungi details are loaded from the fungi subdir in here.
	 */
	FungusFactory();
	///	Destructor.
	~FungusFactory();

	///	Loads the fungi images.
	void loadImages(Drawer *d);

	///	Returns a random fungus.
	Fungus *getRandomFungus();
	///	Returns the number of fungus types.
	int getNumFungusTypes() const {return fungi.size();};

	///	Increments the scanning value for the named type.
	void incScannedVal(const std::string& name);
	///	Returns how much the named type has been scanned.
	float getScannedVal(const std::string& name) const;
  private:
	///	Struct representing a type of fungus.
	struct FungusType
	{
		///	The type's name.
		std::string name;
		///	The type's image.
		uint32_t image;
		///	The type's size.
		float width;
		///	The type's size.
		float height;
		///	The type's collision boxes.
		std::vector<BoundingBox> collisionBoxes;

		///	How much this type has been scanned by the player.
		float scannedVal;
	};

	///	The available types of fungus.
	/*!
		Static so we don't load the fungi images every time we start a game.
	 */
	static std::vector<FungusType> fungi;

	///	The index to the last fungus we generated.
	/*!
		So the RNG doesn't accidentally make things too uniform.
	 */
	int lastFungus;
};

#endif
