//	KillerSpore.cpp - A spore which kills the player on contact.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "KillerSpore.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "Random.h"

#include <cmath>

//------------------------------------------------------------------------------
uint32_t KillerSpore::image = 0;

//------------------------------------------------------------------------------
KillerSpore::KillerSpore():
xPos(1280.0f)
{
	yBase = 72.0f;
	yBase += (Random::getGlobal().getRandomFloat() * (800.0f-144.0f));
	speed = 2.0f + (Random::getGlobal().getRandomFloat() * 2.0f);
	index = Random::getGlobal().getRandomFloat();
	increment = 0.005f;
	yPos = yBase + (sinf(index * 6.283185f) * 32.0f);
}

//------------------------------------------------------------------------------
KillerSpore::~KillerSpore()
{
	
}

//------------------------------------------------------------------------------
bool KillerSpore::move()
{
	bool retval = false;

	xPos -= speed;
	index += increment;
	if(index >= 1.0f)
		index -= 1.0f;
	yPos = yBase + (sinf(index * 6.283185f) * 32.0f);

	if(xPos < -30.0f)
		retval = true;

	return retval;
}

//------------------------------------------------------------------------------
void KillerSpore::draw(Drawer *d)
{
	if(!image)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::spore2_png, Images::spore2_pngSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	d->drawImage(image, xPos, yPos);
}
