//	Player.h - The player's ship.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYER_H_
#define PLAYER_H_

#include "ParticleGenerator.h"

#include <stdint.h>

class Drawer;

///	The player's ship.
class Player
{
  public:
	///	Constructor.
	Player();
	///	Destructor.
	~Player();

	///	Moves the player.
	void move();
	///	Draws the player.
	void draw(Drawer *d);

	///	Kills the player.
	void kill();

	///	Tells the player not to go too near the boss.
	void setBossTime();

	///	Returns whether or not the player is dead.
	bool getDead() const {return dead;};
	///	Returns the player's position.
	float getX() const {return xPos+9.0f+8.0f;};// {return xPos+9.0f;};
	///	Returns the player's position.
	float getY() const {return yPos+21.0f+8.0f;};// {return yPos+21.0f;};
	///	Returns the player's size.
	float getWidth() const {return 105.0f-16.0f;};// {return 105.0f;};
	///	Returns the player's size.
	float getHeight() const {return 62.0f-16.0f;};// {return 62.0f;};

	///	Tells the player to move.
	void moveUp(bool val);
	///	Tells the player to move.
	void moveLeft(bool val);
	///	Tells the player to move.
	void moveRight(bool val);
	///	Tells the player to move.
	void moveDown(bool val);
  private:
	///	The player's image.
	static uint32_t image;
	///	The engine particle.
	static uint32_t particle;
	///	The explosion debris.
	static uint32_t debris[3];

	///	The player's position.
	float xPos;
	///	The player's position.
	float yPos;
	///	The player's speed.
	float xSpeed;
	///	The player's speed.
	float ySpeed;

	///	The engine particles.
	ParticleGenerator particles;
	///	The explosion particles.
	ParticleGenerator explosion;

	///	Whether or not the player is dead.
	bool dead;

	///	Whether or not the boss has appeared.
	bool bossTime;

	///	Which direction the player is moving.
	bool upIsDown;
	///	Which direction the player is moving.
	bool leftIsDown;
	///	Which direction the player is moving.
	bool rightIsDown;
	///	Which direction the player is moving.
	bool downIsDown;
};

#endif
