//	Spore.h - A spore which adds a weapon toadstool to the player if they
//			  collide with it.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef SPORE_H_
#define SPORE_H_

#include <stdint.h>

class Drawer;

///	A spore which adds a weapon toadstool to the player if they collide with it.
class Spore
{
  public:
	///	Constructor.
	Spore();
	///	Destructor.
	~Spore();

	///	Moves the spore.
	bool move();
	///	Draws the spore.
	void draw(Drawer *d);

	///	Returns the spore's position.
	float getX() const {return xPos;};
	///	Returns the spore's position.
	float getY() const {return yPos;};
	///	Returns the spore's radius.
	float getRadius() const {return 10.0f;};
  private:
	///	The spore's image.
	static uint32_t image;

	///	The spore's position.
	float xPos;
	///	The spore's position.
	float yPos;
	///	The spore's speed.
	float speed;
	///	The spore's position in its sine wave.
	float index;
	///	The speed the spore moves through its sine wave.
	float increment;
	///	The spore's baseline y position.
	float yBase;
};

#endif
