//	TextScroller.h - An amiga-esque text scroller.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TEXTSCROLLER_H_
#define TEXTSCROLLER_H_

#include "NiallsDrawingLib/Drawer.h"

#include <cmath>
#include <string>
#include <vector>

///	An amiga-esque text scroller.
class TextScroller
{
  public:
	///	Constructor.
	TextScroller(const std::string& t);
	///	Destructor.
	~TextScroller();

	///	Draws the text.
	void draw(Drawer *d, float y);
  private:
	///	Represents a single character.
	class ScrollerChar
	{
	  public:
		///	Constructor.
		ScrollerChar(const std::string& c):
		character(c),
		bounce(0.0f),
		xPos(224.0f)
		{
			
		};
		///	Destructor.
		~ScrollerChar()
		{
			
		};

		///	Draws the character, returns true if it's moved of the left of the screen.
		bool draw(Drawer *d, float y)
		{
			float tempf;
			float red = (xPos+20.0f)/244.0f;
			float blue = 1.0f-((xPos+20.0f)/244.0f);
			bool retval = false;

			xPos -= 1.0f;
			if(xPos < -20.0f)
				retval = true;
			else
			{
				bounce += 0.03f;
				if(bounce >= 1.0f)
					bounce = 0.0f;
				tempf = sinf(bounce * 2.0f * 3.14159265f) * 3.0f;
				d->drawText(character, xPos, (y+tempf), 16.0f, red, 0.0f, blue);
			}

			return retval;
		};
	  private:
		///	This character.
		std::string character;
		///	The character's bounce.
		float bounce;
		///	The character's x-axis position.
		float xPos;
	};

	///	The entire text to display.
	std::vector<ScrollerChar *> text;
	///	Which character to display next.
	int character;
	///	How many characters are on screen.
	int numChars;
	///	Used to work out when to add a new character to the screen.
	float charTimer;
};

#endif
