//	HorizontalSlider.h - A horizontal slider widget.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef HORIZONTALSLIDER_H_
#define HORIZONTALSLIDER_H_

#include "Widget.h"
#include "Callbacks.h"

#include <stdint.h>

///	A horizontal slider widget.
class HorizontalSlider : public Widget,
						 public ChangeBroadcaster
{
  public:
	///	Constructor.
	HorizontalSlider(const char *imageData,
					 uint32_t imageSize,
					 float handleWidth);
	///	Destructor.
	~HorizontalSlider();

	///	Draws the widget.
	void draw(Drawer *d);

	///	Called when the mouse moves within this widget's bounds.
	void mouseMove(float x, float y);
	///	Called when a mouse button is clicked or released.
	void mouseButton(bool val, float x, float y);
	///	Called when the mouse is outside the widget's bounds.
	void mouseLeave(float x, float y);

	///	Sets the slider's value.
	void setValue(float val);
  private:
	///	The image of the slider's handle.
	uint32_t image;

	///	The slider's value (0->1).
	float value;
	///	The size of the handle.
	float handleSize;
	///	Whether the handle is currently being dragged or not.
	bool dragging;

	///	If the mouse is over the slider handle.
	bool mouseIsOver;

	///	The image's data.
	const char *imageData;
	///	The image's data's size.
	uint32_t imageSize;
};

#endif
