//	RadioButtons.cpp - Basic (vertical) radio buttons widget.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "RadioButtons.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "MouseCursor.h"

//------------------------------------------------------------------------------
RadioButtons::RadioButtons(const char *imageUpData,
						   uint32_t imageUpSize,
						   const char *imageDownData,
						   uint32_t imageDownSize,
						   int num,
						   float height):
Widget(),
ChangeBroadcaster(),
up(0),
down(0),
buttonHeight(height),
numButtons(num),
value(0),
mouseIsDown(false),
mouseIsOver(false),
upData(imageUpData),
upSize(imageUpSize),
downData(imageDownData),
downSize(imageDownSize)
{
	
}

//------------------------------------------------------------------------------
RadioButtons::~RadioButtons()
{
	
}

//------------------------------------------------------------------------------
void RadioButtons::draw(Drawer *d)
{
	int i;
	const float x = getXPos();
	const float y = getYPos();

	if(!up && upData)
	{
		ImageData data;
		ImageLoader loader;

		data = loader.loadImage(upData, upSize);
		up = d->loadImage(data.data, data.width, data.height);

		data = loader.loadImage(downData, downSize);
		down = d->loadImage(data.data, data.width, data.height);
	}

	for(i=0;i<numButtons;++i)
	{
		if(i == value)
			d->drawImage(down, x, y+(i*buttonHeight));
		else
			d->drawImage(up, x, y+(i*buttonHeight));
	}
}

//------------------------------------------------------------------------------
void RadioButtons::mouseMove(float x, float y)
{
	mouseIsOver = true;
	MouseCursor::getInstance().setImage(true);
}

//------------------------------------------------------------------------------
void RadioButtons::mouseButton(bool val, float x, float y)
{
	if(val)
	{
		mouseIsDown = true;
		value = (int)((y-getYPos())/buttonHeight);
		callChangeCallbacks(this, (float)value);
	}
	else
		mouseIsDown = false;
}

//------------------------------------------------------------------------------
void RadioButtons::mouseLeave(float x, float y)
{
	if(mouseIsOver)
	{
		mouseIsOver = false;
		MouseCursor::getInstance().setImage(false);
	}
	mouseIsDown = false;
}

//------------------------------------------------------------------------------
void RadioButtons::setValue(int val)
{
	value = val;
}
