//	StaticImage.h - A static image widget.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef STATICIMAGE_H_
#define STATICIMAGE_H_

#include "Widget.h"

#include <stdint.h>

///	A static image widget.
class StaticImage : public Widget
{
  public:
	///	Constructor.
	/*!
		\param data The image data as a byte buffer.
		\param size The size of data.
	 */
	StaticImage(const char *data, uint32_t size);
	///	Destructor.
	~StaticImage();

	///	Draws the image.
	void draw(Drawer *d);

	///	Called when the mouse moves within this widget's bounds
	void mouseMove(float x, float y) {};
	///	Called when a mouse button is clicked or released.
	void mouseButton(bool val, float x, float y) {};
  private:
	///	The image's id.
	uint32_t image;

	///	The image's data.
	const char *imageData;
	///	The image's data's size.
	uint32_t imageSize;
};

#endif
