//	VerticalSlider.cpp - A vertical slider widget.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "VerticalSlider.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "MouseCursor.h"

//------------------------------------------------------------------------------
VerticalSlider::VerticalSlider(const char *data,
							   uint32_t size,
							   float handleWidth):
Widget(),
ChangeBroadcaster(),
image(0),
value(0.0f),
handleSize(handleWidth),
dragging(false),
mouseIsOver(false),
imageData(data),
imageSize(size)
{
	
}

//------------------------------------------------------------------------------
VerticalSlider::~VerticalSlider()
{
	
}

//------------------------------------------------------------------------------
void VerticalSlider::draw(Drawer *d)
{
	float tempf;
	float x = getXPos();

	if(!image)
	{
		ImageData data;
		ImageLoader loader;

		data = loader.loadImage(imageData, imageSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	tempf = (1.0f-value) * getHeight();
	tempf += getYPos();
	tempf -= (handleSize*0.5f);

	d->drawImage(image, getXPos(), tempf);
}

//------------------------------------------------------------------------------
void VerticalSlider::mouseMove(float x, float y)
{
	float left, right;
	const float w = getHeight();

	mouseIsOver = true;
	MouseCursor::getInstance().setImage(true);

	left = getYPos();
	right = left + w;

	if(dragging)
	{
		if((y >= left) && (y < right))
			value = 1.0f-((y-left)/w);
		else if(y < left)
			value = 1.0f;
		else if(y > right)
			value = 0.0f;
		callChangeCallbacks(this, value);
	}
}

//------------------------------------------------------------------------------
void VerticalSlider::mouseButton(bool val, float x, float y)
{
	float left, right;
	const float w = getHeight();

	if(val)
	{
		left = getYPos();
		right = left + w;

		if((y >= left) && (y < right))
		{
			value = 1.0f-((y-left)/w);
			dragging = true;
		}
	}
	else
		dragging = false;
}

//------------------------------------------------------------------------------
void VerticalSlider::mouseLeave(float x, float y)
{
	float left, right;
	const float w = getHeight();

	if(!dragging && mouseIsOver)
	{
		mouseIsOver = false;
		MouseCursor::getInstance().setImage(false);
	}
	else if(dragging)
	{
		left = getYPos();
		right = left + w;

		if((y >= left) && (y < right))
			value = 1.0f-((y-left)/w);
		else if(y < left)
			value = 1.0f;
		else if(y > right)
			value = 0.0f;
		callChangeCallbacks(this, value);
	}
}

//------------------------------------------------------------------------------
void VerticalSlider::setValue(float val)
{
	value = val;
}
